@@ -2,6 +2,7 @@
 
 import re
 from datetime import datetime, date
+from bs4 import BeautifulSoup
 
 from .aktie import Aktie, Aktionaer
 from .anleihe import Anleihe, Kredit
@@ -43,7 +44,11 @@ class Ag:
 
     @property
     def in_liquidation(self) -> bool:
-        return self._ag_data().get("in_liquidation") == "true"
+        return self._ag_data().get("in_liquidation")
+
+    @property
+    def in_kapitalerhoehung(self) -> bool:
+        return self._ag_data().get("laufende_ke")
 
     @property
     def kurs(self) -> float:
@@ -145,7 +150,7 @@ class Ag:
 
     @property
     def in_agsx(self) -> bool:
-        return self._ag_data().get("in_agsx") == "true"
+        return self._ag_data().get("in_agsx")
 
     @property
     def handelsaktivitaet(self) -> int:
@@ -170,10 +175,11 @@ class Ag:
 
         registrierung_datum = datetime.strptime(self._ag_data().get("ceo").get("registrierung_datum"),
                                                 "%Y-%m-%d %H:%M:%S")
-        gesperrt = self._ag_data().get("ceo").get("gesperrt") == "true"
-        userprojekt = self._ag_data().get("ceo").get("ist_userprojekt_account") == "true"
+        gesperrt = self._ag_data().get("ceo").get("gesperrt")
+        premium = self._ag_data().get("ceo").get("premium")
+        userprojekt = self._ag_data().get("ceo").get("ist_userprojekt_account")
         return Ceo(name=name, index=index, registrierung_datum=registrierung_datum, gesperrt=gesperrt,
-                   userprojekt=userprojekt)
+                   premium=premium, userprojekt=userprojekt)
 
     @property
     def aktien(self) -> list:
@@ -226,7 +232,7 @@ class Ag:
         orders = []
         for i in self._ag_data().get("orders"):
             temp = Order(typ=i.get("typ"), limit=float(i.get("limit")), stueckzahl=int(i.get("stueckzahl")),
-                         orderregel=i.get("orderregel") == "true", systembank=i.get("systembank_order") == "true",
+                         orderregel=i.get("orderregel"), systembank=i.get("systembank_order"),
                          datum=datetime.strptime(i.get("datum"), "%Y-%m-%d %H:%M:%S"))
             orders.append(temp)
 
@@ -288,23 +294,19 @@ class Ag:
 
     @property
     def dividende(self) -> float:
-        table_data = {}
-        rows = self._web_data().find('table', attrs={'class': 'padding5'}).find_all('tr')
-        for row in rows:
-            cols = row.find_all("td")
-            table_data[cols[0].text] = cols[1].text
-
-        return float(re.compile("(0\.?\d{0,2})%").findall(table_data.get("Dividende"))[0])
+        return float(self._ag_data().get("dividende"))
 
     @property
     def max_zertis(self) -> int:
-        table_data = {}
-        rows = self._web_data().find('table', attrs={'class': 'padding5'}).find_all('tr')
-        for row in rows:
-            cols = row.find_all("td")
-            table_data[cols[0].text] = cols[1].text
+        return int(float(self._ag_data().get("max_zertifikate_anteil")) * 100)
 
-        return int(re.compile("(\d{1,2})%").findall(table_data.get("Max. Zertifikatevol."))[0])
+    @property
+    def max_zertis_aenderbar(self) -> bool:
+        return self._ag_data().get("max_zertifikate_anteil_aenderbar")
+
+    @property
+    def uebernahmeschutz(self) -> bool:
+        return self._ag_data().get("uebernahmeschutz")
 
     @property
     def tages_hoch(self) -> float:
